@@ -183,7 +183,7 @@ class Todo(ModelSQL, ModelView):
         return res
 
     def search_calendar_field(self, name, clause):
-        return [('calendar.' + name[9:],) + clause[1:]]
+        return [('calendar.' + name[9:],) + tuple(clause[1:])]
 
     def check_recurrence(self, ids):
         '''
@@ -229,11 +229,13 @@ class Todo(ModelSQL, ModelView):
                             new_id = self.copy(todo.id, default={
                                 'calendar': calendar_id,
                                 'occurences': None,
+                                'uuid': todo.uuid,
                                 })
                             for occurence in todo.occurences:
                                 self.copy(occurence.id, default={
                                     'calendar': calendar_id,
                                     'parent': new_id,
+                                    'uuid': occurence.uuid,
                                     })
                     else:
                         parent_ids = self.search([
@@ -246,6 +248,7 @@ class Todo(ModelSQL, ModelView):
                             self.copy(todo.id, default={
                                 'calendar': parent.calendar.id,
                                 'parent': parent.id,
+                                'uuid': todo.uuid,
                                 })
         # Restart the cache for todo
         collection_obj.todo.reset()
@@ -343,11 +346,13 @@ class Todo(ModelSQL, ModelView):
                                 new_id = self.copy(todo.id, default={
                                     'calendar': calendar_id,
                                     'occurences': None,
+                                    'uuid': todo.uuid,
                                     })
                                 for occurence in todo.occurences:
                                     self.copy(occurence.id, default={
                                         'calendar': calendar_id,
                                         'parent': new_id,
+                                        'uuid': occurence.uuid,
                                         })
                         else:
                             parent_ids = self.search([
@@ -361,6 +366,7 @@ class Todo(ModelSQL, ModelView):
                                 self.copy(todo.id, default={
                                     'calendar': parent.calendar.id,
                                     'parent': parent.id,
+                                    'uuid': todo.uuid,
                                     })
         # Restart the cache for todo
         collection_obj.todo.reset()
@@ -428,7 +434,7 @@ class Todo(ModelSQL, ModelView):
         new_ids = []
         for todo_id in ids:
             current_default = default.copy()
-            current_default['uuid'] = self.default_uuid()
+            current_default.setdefault('uuid', self.default_uuid())
             new_id = super(Todo, self).copy(todo_id, default=current_default)
             new_ids.append(new_id)
 
